DatabaseConnector

Trait DatabaseConnector 

pub trait DatabaseConnector: Send + Sync {
    // Required methods
    fn connect<'life0, 'async_trait>(
        &'life0 mut self,
    ) -> Pin<Box<dyn Future<Output = Result<(), DataProfilerError>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;
    fn disconnect<'life0, 'async_trait>(
        &'life0 mut self,
    ) -> Pin<Box<dyn Future<Output = Result<(), DataProfilerError>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;
    fn profile_query<'life0, 'life1, 'async_trait>(
        &'life0 mut self,
        query: &'life1 str,
    ) -> Pin<Box<dyn Future<Output = Result<HashMap<String, Vec<String>>, DataProfilerError>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait,
             'life1: 'async_trait;
    fn profile_query_streaming<'life0, 'life1, 'async_trait>(
        &'life0 mut self,
        query: &'life1 str,
        batch_size: usize,
    ) -> Pin<Box<dyn Future<Output = Result<HashMap<String, Vec<String>>, DataProfilerError>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait,
             'life1: 'async_trait;
    fn get_table_schema<'life0, 'life1, 'async_trait>(
        &'life0 mut self,
        table_name: &'life1 str,
    ) -> Pin<Box<dyn Future<Output = Result<Vec<String>, DataProfilerError>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait,
             'life1: 'async_trait;
    fn count_table_rows<'life0, 'life1, 'async_trait>(
        &'life0 mut self,
        table_name: &'life1 str,
    ) -> Pin<Box<dyn Future<Output = Result<u64, DataProfilerError>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait,
             'life1: 'async_trait;
    fn test_connection<'life0, 'async_trait>(
        &'life0 mut self,
    ) -> Pin<Box<dyn Future<Output = Result<bool, DataProfilerError>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;
}
Trait that all database connectors must implement

Required Methods

fn connect<'life0, 'async_trait>( &'life0 mut self, ) -> Pin<Box<dyn Future<Output = Result<(), DataProfilerError>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

Connect to the database

fn disconnect<'life0, 'async_trait>( &'life0 mut self, ) -> Pin<Box<dyn Future<Output = Result<(), DataProfilerError>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

Disconnect from the database

fn profile_query<'life0, 'life1, 'async_trait>( &'life0 mut self, query: &'life1 str, ) -> Pin<Box<dyn Future<Output = Result<HashMap<String, Vec<String>>, DataProfilerError>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait,

Execute a query and get column data for profiling

fn profile_query_streaming<'life0, 'life1, 'async_trait>( &'life0 mut self, query: &'life1 str, batch_size: usize, ) -> Pin<Box<dyn Future<Output = Result<HashMap<String, Vec<String>>, DataProfilerError>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait,

Execute a query with streaming for large result sets

fn get_table_schema<'life0, 'life1, 'async_trait>( &'life0 mut self, table_name: &'life1 str, ) -> Pin<Box<dyn Future<Output = Result<Vec<String>, DataProfilerError>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait,

Get table schema information

fn count_table_rows<'life0, 'life1, 'async_trait>( &'life0 mut self, table_name: &'life1 str, ) -> Pin<Box<dyn Future<Output = Result<u64, DataProfilerError>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait,

Count total rows in table (for progress tracking)

fn test_connection<'life0, 'async_trait>( &'life0 mut self, ) -> Pin<Box<dyn Future<Output = Result<bool, DataProfilerError>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

Test connection

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors